#
# spec file for package feh
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           feh
Version:        3.10.3
Release:        1.5
Summary:        X11 image viewer
License:        LGPL-2.0-or-later AND MIT
URL:            https://feh.finalrewind.org/
Source:         https://feh.finalrewind.org/%{name}-%{version}.tar.bz2
Source1:        https://feh.finalrewind.org/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
Source3:        jpegexiforient.c
Source4:        https://git.finalrewind.org/zsh/plain/etc/completions/_feh
Source99:       feh-rpmlintrc
# PATCH-FIX-OPENSUSE feh-makefile_optflags.patch https://github.com/derf/feh/issues/71 pascal.bleser@opensuse.org -- pass OPTFLAGS to make instead of hard-coded -O2 -g
Patch1:         feh-makefile_optflags.patch
# PATCH-FIX-UPSTREAM https://github.com/derf/feh/pull/337
Patch6:         feh-makefile_app.patch

Patch7:         feh-add_jxl_support.patch
BuildRequires:  curl-devel
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xt)
Requires:       imlib2-loaders
# Needs only the binaries from it. (boo#1080592)
Requires:       libjpeg-turbo
Requires(post): desktop-file-utils
Requires(post): hicolor-icon-theme
Requires(postun): desktop-file-utils
Requires(postun): hicolor-icon-theme

%description
feh is an X11 image viewer aimed mostly at console users. It does not
have a fancy GUI, but simply displays images. It is controlled via
commandline arguments and configurable key/mouse actions. feh has
multiple file modes using a slideshow or multiple windows. It
supports the creation of montages as index prints with many
user-configurable options.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
ZSH completion script for %{name} 3.

%prep
%autosetup -p1
cp %{SOURCE3} .

%build
%make_build \
    PREFIX="%{_prefix}" \
    curl=1 \
    help=1 \
    xinerama=1 \
    debug=0 \
    exif=1 \
    app=1 \
    inotify=1 \
    OPTFLAGS="%{optflags} -Wall -Wextra"

gcc %{optflags} -fwhole-program jpegexiforient.c -o jpegexiforient

%install
%make_install \
    PREFIX="%{_prefix}" \
    cam=1 app=1 examples=0

rm -rf "%{buildroot}%{_datadir}/doc"

install -D -m0755 jpegexiforient %{buildroot}%{_bindir}/jpegexiforient

install -Dm0644 %{SOURCE4} %{buildroot}/%{_datadir}/zsh/site-functions/_%{name}

%files
%license COPYING
%doc AUTHORS ChangeLog README.md TODO
%{_bindir}/feh
%{_bindir}/jpegexiforient
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_mandir}/man1/feh.1%{?ext_man}

%files zsh-completion
%{_datadir}/zsh

%changelog
* Tue Jul  2 2024 Dirk Müller <dmueller@suse.com>
- update to 3.10.3:
  * Fix feh not respecting aspect ratio of thumbnails that are
    smaller than --thumb-width and --thumb-height
  * Fix --no-recursive behaving like --recursive
  * Fix rotation by 180° corrupting images
  * Speed up --sort=size and --sort=mtime by caching stat(2)
    calls
* Sun Jan 28 2024 Mazin Alhaddad <mazin@getstate.dev>
- Update to 3.10.2
  * Fix crash in right-click / menu rendering code on some distributions
- Drop 'feh-fix_pointer_arithmetics.patch'
- Update keyring
* Sun Sep 18 2022 Dirk Müller <dmueller@suse.com>
- update to 3.9.1:
  * Set libcurl user agent to "feh/3.9.1". Previously, feh did not send a
    user agent.
* Thu Aug 11 2022 Enrico Belleri <idesmi@protonmail.com>
- Add feh-add_jxl_support.patch for the image/jxl MimeType to be
  supported.
* Mon Jul  4 2022 Enrico Belleri <idesmi@protonmail.com>
- Update to version 3.9:
  * Remove magic byte check before passing an image to Imlib2.
    This check was introduced in feh 3.6 to work around an issue with
    Imlib2 being slow to determine image loadability in some cases
    <https://phab.enlightenment.org/T8739>. By now, an Imlib2 version
    without this issue is availble.
  * Fix crash (segmentation fault due to null pointer dereference)
    when toggling fullscreen mode while moving the cursor.
  * feh no longer supplies its own getopt_long function.
    getopt_long is provided by a wide range of libc implementations,
    so there is no need for feh to duplicate it.
- Add zsh completion
* Thu May 12 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.8:
  * Add button ID "0" to cursor bindings. This pseudo-button is
    triggered whenever feh observes a cursor movement.
    It does not have a default binding.
  * Support hexadecimal IDs in --window-id
  * Disable --auto-rotate in feh builds compiled with Imlib2 1.7.5
    or later. Imlib2 1.7.5 introduces transparent EXIF-based image
    orientation adjustment, so --auto-rotate is no longer needed
* Mon Nov  1 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.7.2:
  * Fix crash when running feh without stdin file descriptor
  * Support JPEG XL files when using imlib2-jxl
  * Fix support for images smaller than 16 bytes
  * Fix some out of bounds reads
* Wed May 12 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.7.0:
  * Use compact representation instead of key-value pairs for common
    EXIF data
  * Add --window-id <windowid> option (draw to an existing window)
  * Add --zoom-step <percent> option (specify zoom step size)
  * Pass gopher:// and gophers:// URLs to libcurl
  * Fix --reload / --auto-reload reloading the wrong directory when
    using --start-at and no file arguments or filelists have been
    specified
  * Fix Ctrl+key causing unintended behaviour when controlling feh
    via stdin
  * Fix high CPU usage when closing stdin after starting feh from
    a terminal
* Tue Jan 26 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.6.3:
  * Fix --start-at not handling URL-encoded file:/// paths properly. Notably,
    this also fixes feh not displaying images with spaces or unicode
    elements in their path when opened from a file manager.
* Sat Jan 16 2021 Avindra Goolcharan <avindra@opensuse.org>
- Update to 3.6.2:
  * Fix save_filelist not respecting --output-dir
  * Fix file descriptor leak when attempting to load truncated image
    files (introduced with v3.6)
- manually require libjpeg-turbo for jpegtran. fixes --edit (boo#1080592)
- add feh-rpmlintrc
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- update to 3.6.1:
  * Fix excessive memory consumption when showing long-running slideshows
    with thousands to tens of thousands of images and feh has been compiled
    with exif=1 (see https://github.com/derf/feh/issues/553)
  * Fix memory leak when showing long-running slideshows with relatively few
    images and feh has been compiled with exif=1 (ibid.)
  * Fix memory leak when reloading an image and feh has been compiled with
    exif=1
  * Fix memory leak in --draw-exif
  * Fix memory leak when reloading HTTP files with --no-conversion-cache
  * Add flip and rotate options to the menu
  * Improve unloadable image detection time (e.g. for large video files) by
    checking a file's header before passing it to Imlib2. For rarely used
    image formats, there is a very small chance that an image which could be
    loaded by feh 3.5 is reported as unloadable by feh 3.6 due to this
    change. Set FEH_SKIP_MAGIC=1 to bypass the header check in this case. See
    <https://phab.enlightenment.org/T8739> and
    <https://github.com/derf/feh/issues/505> for details.
* Sat Sep 12 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.5:
  * Enable --version-sort on systems without strverscmp support.
  * Add %%a format specifier (slideshow state: "playing" / "paused")
  * Fix crashes when combining --reload and --multiwindow
* Fri Jun 19 2020 Ismail Dönmez <idonmez@suse.com>
- Enable inotify support for automatic reload.
* Mon Jun  1 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.4.1
  * Fix lossless JPG rotate not being lossless when using feh with Imlib2 v1.6 or later
* Wed May  6 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.4:
  * Images loaded via HTTPS/curl, ImageMagick, and dcraw are now cached by
    default.
  * Handle SIGINT/SIGTERM/SIGQUIT signals while loading images
  * "feh --start-at URL" now loads a single-image slideshow
  * Fix a memory leak when repeatedly cycling through slideshows.
* Thu Jan 23 2020 Martin Rey <mrey@suse.com>
- update to 3.3
  * New option --class allows setting the X11 class hint per feh
    instance
  * Improve handling of NULL returns from Imlib2 calls
  * Fix compilation with libcurl < v7.32
- feh-makefile_optflags.patch: Adapt patch to feh 3.3
* Tue Nov  5 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 3.2.1
  * Use --no-fehbg option in ~/.fehbg
  * Fix TOCTTOU when setting the file mode of ~/.fehbg
  * Fix insufficient error handling when updating ~/.fehbg
  * Reload current image(s) when receiving SIGUSR1 or SIGUSR2
* Mon Feb 18 2019 seanlew@opensuse.org
- update to 3.1.3
  * Fix missing filename in ~/.fehbg when using --no-xinerama
* Sun Jan  6 2019 sean@suspend.net
- update to 3.1.1
  * Decrease libcurl timeout from indefinite to 30m
  * Handle SIGINT/SIGTERM/SIGQUIT signals when loading via libcurl
* Tue Nov 13 2018 sean@suspend.net
- update to 3.0
  * Remove deprecated webcam scripts (feh-cam and gen-cam-menu)
  * Remove deprecated collage mode (-c/--collage)
  * Remove deprecated option --cycle-once
  * Remove deprecated options --menu-bg
  * Change default save_filelist key from "f" to "L"
  * Add option --edit, which makes flip and rotation change the
    underlying file as well as the displayed image. This was the
    default behavior in feh 1.x and 2.x
  * Change default toggle_fullscreen key from "v" to "f" as this
    is also used by mplayer, mpv and similar
  * flip and rotation (keys "<", ">", "||, amd "_") no longer change
    the underlying file. This leaves delet ("Ctrl+Delete") as the
    only destructive action which is enabled by default
* Tue Nov  6 2018 sean@suspend.net
- update to 2.28.1
  * Do not ignore quit signals (SIGTERM, SIGINT, SIGQUIT) during preload
  * Add missign EXIF orientations 2,4,5 and 7 (when built with exif=1)
  * Improve randomness on non-glibc systems
* Thu Oct 18 2018 sean@suspend.net
- update to 2.28
  * Decrease loading time for RAW images by utilizing dcraw
  * Rename --magick-timeout to --conversion-timeout
  * New option: --on-last-slide=hold|quit|resume
  * Fix unintended aliasing in rotated images
* Fri Jul 20 2018 mimi.vx@gmail.com
- update to 2.27.1
- fix boo#1101466  - specify PREFIX also for build
  * Fix --keep-zoom-vp issues introduced in 2.27
  * Fix feh occasionally becoming unresponsive when asked
    to terminate via SIGINT/SIGQUIT/SIGTERM
  * Fix size_to_image ("w") command when both --scale-down and
  - -keep-zoom-vp are enabled
  * Fix --auto-zoom not being triggered on window resize events
    when --scale-down is enabled
  * Fix --auto-zoom conflicting with manual zoom
  * Prevent --zoom <percent> from blocking --scale-down in fullscreen
    / fixed geometry mode
  * Prevent --keep-zoom-vp from blocking the dynamic window resizing mechanism
  - Prevent automatic recalculation of the zoom ratio when
  - -keep_zoom_vp is enabled
* Sun Jun 10 2018 antoine.belvire@opensuse.org
- Update to 2.26.3:
  * Properly escape --image-bg argument in ~/.fehbg (broken in
    2.26.1).
- Update to 2.26.2:
  * Show correct filelist position in windows opened from thumbnail
    mode.
  * Note that navigation is still not supported in those windows.
  * Improve support for key input from stdin.
  * Do not push menus off the screen when hitting screen limits.
* Sat May 12 2018 avindra@opensuse.org
- Update to 2.26.1
  * Restore pre-2.21 ~/.fehbg behaviour. This fixes nondeterministic
    wallpaper setting when using --bg-* --randomize, issues when
    specifying --theme both in ~/.fehbg and on the commandline, and
    possibly other edge cases
  * Fix /tmp being cluttered with temp ImageMagick files when using
  - -magick-timeout and a conversion takes longer than allowed
* Wed May  9 2018 pvorel@suse.cz
- Update to 2.26
  * Save absolute file paths in ~/.fehbg, similar to behaviour prior
    to 2.21
  * Add %%g (window dimensions) and %%Z (precise zoom level) format
    specifiers
  * Improve -z/--randomize randomness
* Mon Mar 12 2018 avindra@opensuse.org
- Update to 2.25.1
  * Re-render current image when toggle_fixed_geometry is input
  * Fix issues when using CFLAGS=-m64 on some gcc versions
- run spec-cleaner
* Wed Mar  7 2018 mvetter@suse.com
- Update to 2.25
  * Add --version-sort option to enable natural sorting of file
    and directory names
  * Allow arbitrary X11 colors as -B/--image-bg argument
  * Improve --image-bg support and transparency handling in
  - -bg-* mode
  * Respect --geometry settings in --bg-fill mode
  * Add keybinding toggle_auto_zoom (default "Z") to toggle
  - -auto-zoom
  * Fix filelists specified by -f/--filelist not being reloaded
    when using --reload
* Mon Feb 26 2018 avindra@opensuse.org
- update to 2.24
  * Improve performance when using --{max,min}-dimension in
    slideshow mode
  * Fix crash when using %%m format specifier in slideshow mode
* Sun Feb 18 2018 avindra@opensuse.org
- update to 2.23.2
  * Fix support for nested quotes in .config/feh/themes
- feh-makefile_app.patch
  * use DESTDIR variable
- spec file: simplify a bit
* Tue Feb 13 2018 crrodriguez@opensuse.org
- Remove BuildRequires on xorg-x11-* metapackages
- Remove unused buildRequires.
* Thu Feb  1 2018 avindra@opensuse.org
- update to 2.23.1
  * The Makefile no longer honors CPPFLAGS and instead consistently
    uses CFLAGS for user-provided include paths
  * Fix %%u format specifier in multiwindow and list modes
  * Minor performance improvements
  * Stability improvements when using --magick-timeout
- switch to https version of website
- rebase feh-makefile_optflags.patch
* Fri Dec 29 2017 jengelh@inai.de
- Ensure neutrality of description.
* Thu Dec 28 2017 avindra@opensuse.org
- update to 2.23
  * Fix broken thumbnail/index windows when using --scale-down
  * Use Imlib2 as in-memory image cache (default size: 4MiB)
    noticable performance improvements, especially in small
    slideshows
  * Add --cache-size option to set Imlib2 image cache size
- rebase feh-makefile_optflags.patch
* Wed Nov  8 2017 aavindraa@gmail.com
- update to 2.22.2
  * Fix HTTPS certificate errors on some systems (broken in 2.22)
* Tue Nov  7 2017 aavindraa@gmail.com
- update to 2.22.1
  * Allow ~/.fehbg to be sourced (instead of executed) from other
  shell scripts again (broken in 2.22)
* Sat Nov  4 2017 aavindraa@gmail.com
- Rebase feh-makefile_app.patch
- update to 2.22
  * Add support for CURL_CA_BUNDLE environment variable when loading
  images via HTTPS
  * Fix ~/.fehbg not being updated when setting a wallpaper via menu
  (broken in 2.21)
* Sun Oct  8 2017 aavindraa@gmail.com
- Drop feh-2.12-fix_sighandler.patch, fixed upstream
- update to 2.21
  * Add toggle_fixed_geometry (g) key binding to toggle window auto-resize
  * Improve control via terminal input
  * Fix crash (segmentation fault) when using feh -O in non-index mode
  * Fix --force-aliasing (and possibly other options) missing from ~/.fehbg
    when using them for background setting
- includes changes from 2.20
  * Fix clang/gcc warnings
  * Add support for control via terminal input. feh will read key presses
  from the controlling terminal and handle them like X11 key presses
  inside the feh window. Note that at the moment, only lower / upper case
  ASCII letters and a very small set of additional keys are supported.
  * Fix broken ImageMagick support (see --magick-timeout) when using some ImageMagick versions
  * Remove images from the filelist if they were removed by executing a user-defined action
- includes changes from 2.19.1 - 2.19.3:
  * Fix Shift modifier not being recognized for tab, space and similar keys.
  This lead to keybindings like Shift+Tab or Shift+Space being parsed as
  if the Shift modifier had not been specified
  * Show ImageMagick loader errors unless --quiet is specified
  * Fix crash when handling certain media keys (introduced in 2.19.1)
  * Save geometry data in .fehbg when setting a wallpaper with --geometry
  * Fix Imlib2 developer warning and improve out-of-memory error message when using --thumbnails / --index on large directories
* Sun Jun 18 2017 mimi.vx@gmail.com
- update to 2.19
  * Follow the freedesktop.org Thumbnail Managing Standard by saving thumbnails
    in ${XDG_CACHE_HOME}/thumbnails (defaulting to ~/.cache/thumbnails)
    instead of ~/.thumbnails
  * Install app icons with the correct permissions of 644
  * Documentation improvements
* Wed Apr 19 2017 mimi.vx@gmail.com
- update to 2.18.3
- fixes boo#1034567 - CVE-2017-7875
  * Fix double-free/OOB-write in E17 IPC. This only affects the background
    setting options and requires a malicious X11 app to run alongside feh
    and pretend to be an E17 window manager.
  * Fix image-specific format specifiers not being updated correctly in thumbnail
    mode window titles
  * Fix memory leak when closing images opened from thumbnail mode
  * Fix a possible out of bounds read caused by an unterminated string when
    using --output to save images in long paths
  * Fix out of bounds read/write when handling empty or broken caption files.
  * Fix memory leak when saving a filelist or image whose target filename
    already exists.
* Fri Feb 24 2017 mimi.vx@gmail.com
- update to 2.18.2
  * Fix image-specific format specifiers not being updated correctly
  * New key binding: ! -  zoom_fill (zoom to fill window, may cut off image parts
  * Disable EXIF-based auto rotation by default
  * add --auto-rotate option to enable auto rotation
* Thu Sep  1 2016 mimi.vx@gmail.com
- update to 2.17.1
- added feh-makefile_app.patch -- fix install location of icons
- refreshed feh-makefile_optflags.patch
  * Install feh icon (both 48x48 and scalable SVG) to /usr/share/icons
    when running "make install app=1"
  * Fix --sort not being respected after the first reload when used in
    conjunction with --reload
  * All key actions can now also be bound to a button by specifying them
    in .config/feh/buttons. However, note that button actions can not be
    bound to keys.
  * Rename "menu" key action to "toggle_menu", "prev" to "prev_img" and
    "next" to "next_img". The old names are still supported, but no longer
    documented.
  * feh now also sets the X11 _NET_WM_PID and WM_CLIENT_MACHINE window
    properties
  * Fix compilation on systems where HOST_NAME_MAX is not defined
* Wed Aug 10 2016 mimi.vx@gmail.com
- update to 2.16.2
- refreshed patches:
  feh-2.12-fix_sighandler.patch
  feh-fix_pointer_arithmetics.patch
  feh-makefile_optflags.patch
- dropped patch: feh-no_date.patch
  * Also support in-place editing for images loaded via libcurl or
    imagemagick. Results will not be written back to disk in this case.
  * Fix crash when trying to rotate a JPEG image without having
    jpegtran / jpegexiforient installed
  * Handle failing fork() calls gracefully
  * Fix invalid key/button definitions mis-assigning keys/buttons to other
    actions
  * Add sort mode --sort dirname to sort images by directory instead
    of by name. For example, where a normal recursive run will show images in
    the order foo/a.jpg -> foo/bar/baz.jpg -> foo/fnord.jpg, a dirname sort
    will result in foo/a.jpg -> foo/fnord.jpg -> foo/bar/baz.jpg (Patch by
    Sung Pae)
  * Add navigation keys next_dir (]) and prev_dir ([) to jump to the first
    image of the nex/previous directory (Patch by Sung Pae)
  * Fix toggle_filenames key displaying wrong file numbers in multiwindow
    mode
  * Rescale image when resizing a window and --scale-down or --geometry is
    active. This largely fixes the --scale-down issues introduced in
    2.15. However, note that --scale-down still introduces a fixed window
    size which will not be updated when changing images (as was the case in
    feh < 2.15). This may or may not be fixed in the future.
  * Fix --keep-zoom-vp not keeping the viewport x/y offsets (broken by 2.15)
  * Fix w (size_to_image) key not updating window size when --scale-down
    or --geometry is active
  * Patch by William Woodruff: Add --insecure option to disable HTTPS
    certificate checks
  * Patch by guraga: Add --no-recursive option to disable recursive directory
    expansion.  Note that --no-recursive is the default behaviour of feh.
    This option is mostly useful to override a --recursive set in a theme or
    shell alias
  * Patch by Richard Molitor: Improve --scale-down in tiling environments.
    This fixes flickering when changing images at the cost of slightly
    less apaptive scale-down behaviour: Window size changes are now only
    processed when the active image is changed
  * --action and --action[1..9] now support action titles
    (e.g. --action '[some title]some-command %%F'), which are displayed
    instead of the specified shell command. Note that the title must not
    start with a space. Titles starting with a space are treated as part of
    of the command so that actions like '[ -L %%F ] && foo' still work
  * make test: Ignore results on arm and mips since they expose a bug in
    Imlib2 1.4.7 and/or giflib 5.1.2. Note that due to this bug, feh may be
    unable to display gif images. x86 and amd64 are also affected.
    Again, see <https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=813729>
    for more information
  * -f / --filelist: Do not print useless error message when a correct
    filelist file is specified
  * -f / --filelist: Fix bug in "-" / "/dev/stdin" handling affecting feh
    running in ksh and possibly other environments
* Thu May 26 2016 mvetter@suse.com
- Don't display feh in menu (can't start it without parameters anyways)
* Sun Nov 29 2015 mimi.vx@gmail.com
- fix bsc#955576
- add jpegexiforient to package
* Sat Oct 24 2015 mimi.vx@gmail.com
- update to 2.14
  * Add --xinerama-index option for background setting
  * When removing the last image in slidsehow mode, stay on the last (previously
    second-to-last) image
  * Allow --sort and --randomize to override each other (most recently specified
    option wins) instead of always preferring --sort
  * Thumbnail mode: Mark image as processed when executing an action (--action) by
    clicking on an image
  * It is now possible to override feh's idea of the active xinerama screen using the
  - -xinerama-index option
  * Remove (undocumented) feature allowing to override feh's idea of the active
    xinerama screen by setting the XINERAMA_SCREEN environment variable
- remove obsolete gpg macro
* Wed Jul  8 2015 mimi.vx@gmail.com
- update to 2.13.1
  * Fix --scale-down breaking image centering in fullscreen mode
- spec-cleaned
* Tue May 12 2015 seiler@b1-systems.de
- update to 2.21.2
  * Handle missing HOME in environment
  * Fix memory leak when a slideshow contains many unloadable images
  * Fix memory leak when --prelaod removes files from the filelist
- added dependency because of missing image loader:
  feh WARNING: example.jpg - No Imlib2 loader for that file format
- removed unneeded dependency giblib (unmaintained)
* Tue Sep  2 2014 toganm@opensuse.org
- Update to 2.12
  * feh no longer depends on giblib. Instead, the relevant parts
    of the giblib source were imported into the feh source.
    Rationale: giblib is unmaintained and, as far as I know, only
    used by three projects (one of which is feh). There is at least one
    known bug in it, and as I do not have the time to take over giblib
    development, importing the library seems to be the best solution.
  * Fix/improve --randomize for short filelists (closes #151)
  * Fix a buffer overflow in the printf implementation when
  * handling unknown format specifiers (affects --action, --customlist,
  - -index-info, --info, --thumb-title and --title)
  * Update help (if built with help=1)
- Patches reworked for patch level 1
  * replaced feh-fix_sighandler.patch with feh-2.12-fix_sighandler.patch
* Thu Apr 10 2014 seiler@b1-systems.de
- update to 2.10
  * Allow non-centered wallpapers using the --geometry option
  (Patch by Joel Bradshaw)
  * Add ; flag to --info (as in "--info ';echo foo'") to disable info
  display on startup
  * Partially fix off-by-one pixel error when warping the pointer in the
  bottom/right window border
  * thumbnail mode: If --action is set, run specified command instead of
  opening image on click.
  * feh.desktop: Use feh %%F since we support multiple files
  * Fix --borderless not working on some 64bit systems
  (Patch by Brian Mattern)
  * Always use absolute paths in .fehbg
- patches included:
  * feh-makefile_optflags.patch: added optflags to makefile
  * feh-no_date.patch: removed build date to prevent OBS to rebuild
  * feh-fix_sighandler.patch: changeg value of sighandler
  * feh-fix_pointer_arithmetics.patch: corrected variable of pointe
    arithmetics
* Thu Aug  1 2013 vcizek@suse.com
- update to 2.9.3
  * Patch by David Gowers: Add %%L format code (temporary copy of filelist)
  * Fix buffer overflows in printf implementation (affects --action,
  - -customlist, --index-info, --info, --thumb-title, --title)
  * Fix tests failing when compiled with help=1
  * Fix -F --zoom 100 not working in Gnome+Unity when compiling feh with
    gcc and enabled optimizations (not -O0)
  * EXIF updates by Dennis Real
- added gpg tarball checking
- fix the licence format
* Tue Feb 19 2013 nmo.marques@gmail.com
- update to 2.9.1:
  * Set correct window dimensions on any Xinerama screen, not just the
    first one (active screen is determined by current pointer location)
- fixes from 2.9:
  * Add --keep-zoom-vp option to keep zoom and offsets when switching
    images (patch by sdaau). Press 'k' to toggle it.
  * Add --sort mtime option (patch by guns)
  * Add a desktop file (installed to share/applications/feh.desktop)
  * Use "feh -" to read image from stdin
  * Fix Imlib2 and X11 warnings when opening a URL that returned an HTTP
    error
  * Add button bindings to zoom in / out (patch by sdaau)
- Rebase %%%%patch1
* Tue Dec 25 2012 pascal.bleser@opensuse.org
- update to 2.8:
  * Do not apply --scale-down to the thumbnail window. It will be applied
    to windows opened from this, though.
  * Respect --image-bg when setting a wallpaper (bg-center and bg-max)
  * Add %%V (feh process ID) format specifier
  * Fix delete not working on last image with --cycle-once
  * Treat quick, low-offset drags (1px or 2px move in <1 second) as clicks
    to improve graphics tablet support
  * Respect --start-at in thumbnail mode
  * Make 'z' (jump_random) work in thumbnail mode as well, fix thumbnail
    selection roll-over
* Tue Oct 16 2012 pascal.bleser@opensuse.org
- update to 2.7:
  * add --min-dim and --max-dim options to only process images with certain
    dimensions
* Thu Sep 27 2012 pascal.bleser@opensuse.org
- update to 2.6.3:
  * Fix segfault when doing lossless mirror/rotate and jpegexiforient is
    not present: https://github.com/derf/feh/issues/100
* Thu Sep 27 2012 pascal.bleser@opensuse.org
- update to 2.6.2:
  * Set EXIF orientation tag to 1 ("0,0 is top left" aka normal) after
    running jpegtran. Previously, when doing a lossless rotate, the image
    was rotated but the corresponding EXIF tag not updated, resulting in
    wrong image display in programs aware of this EXIF tag.
  * Fix spelling in feh(1)
* Thu Sep 13 2012 pascal.bleser@opensuse.org
- update to 2.6.1:
  * Fix freedesktop.org Thumbnail Managing Standard implementation:
    when running feh on the current working directory, '/path/to/./image.png'
    was used for thumbnail name generation. Now it is always
    '/path/to/image.png'
  * Show error message if lossless rotate / flip failed on non-JPEG image
  * Show error message if -O / -o failed to save image
  * Show error message if load failed and magick is disabled (was broken
    by feh 2.4)
* Fri Sep  7 2012 toganm@opensuse.org
- update to 2.6:
  * Dennis Real: EXIF mode fixes, support for more camera models
  * feh(1): Document behaviour for duplicate key bindings
    <https://github.com/derf/feh/issues/91>
  * menu: simpler background, remove drop shadows
  * Remove --menu-style support (deprecated in 1.12)
  * Allow --slideshow-delay and --reload to be used together
  * New format specifiers:
  * * %%o    x,y image offset relative to top-left window corner
  * * %%r    image rotation
  * * %%z    image zoom
  * Always use file URL as filename when opening http files.
    (consequence: lossless rotate no longer works for such files)
  * --reload now accepts non-decimal values
  * Fix --filelist trying to load .txt files with imagemagick
  * imagemagick support is now disabled by default, to make feh
  * behaviour less confusing. Set --magick-timeout to a non-negative
    value to enable it (--magick-timeout 5 for feh-2.5 behaviour)
- convert license tag to spdx format
* Thu Apr  5 2012 pascal.bleser@opensuse.org
- update to 2.5:
  * add R, * and / bindings for <keypad begin>, <keypad *> and <keypad />
  * try to convert unloadable files with imagemagick for up to 5 seconds
  * add --magick-timeout option to set imagemagick conversion timeout or
    disable it altogether
  * clean up temporary / to-delete files when receiving SIG{INT,TERM,QUIT}
  * do not scroll past image borders when using key bindings
  * --loadable / --unloadable: indicate result in exit status
* Tue Mar  6 2012 pascal.bleser@opensuse.org
- update to 2.4:
  * exif-support fixes
  * format specifier %%S now uses the appropriate suffix (B/kB/MB)
  * format specifier %%P now prints the number of pixels with k/M suffix, like
    %%S. Printing the program name ("feh") is no longer supported
  * feh --list now uses %%S/%%P to print image size and amount of pixels
  * make --quiet and --verbose behave more like their documented way, never
    ignore out of memory errors
  * use ImageMagick (convert) as loader for unsupported file formats
* Wed Nov  2 2011 pascal.bleser@opensuse.org
- update to 2.1:
  * experimental --scale-down and --auto-zoom tiling support (--scale-down is
    now re-applied every time the image is resized):
    https://github.com/derf/feh/issues/54
  * fix http image load for long image names (debian#646421)
* Mon Oct 10 2011 pascal.bleser@opensuse.org
- update to 2.0:
  * the --bg-options now accept multiple filenames, one per Xinerama screen
  * fix --info bug when the command wrote no lines to stdout
  * the button-options -0 through -9 are no longer supported; use
    .config/feh/buttons instead (see feh manpage)
  * new format specifier: %%S (size in kB)
  * the --index-{dim,name,size} options are no longer supported; use
  - -index-info <string> with format specifiers instead
  * the thumbnail index now supports actions on the currently selected
    thumbnail
  * feh now supports 'make stat64=1' to access CIFS shares mounted from 64bit
    hosts if the local system is 32bit (for 32<->32 and 64<->64, this works
    anyways)
* Tue Sep 27 2011 pascal.bleser@opensuse.org
- update to 1.16.2:
  * fix useless memory use when using feh --reload on HTTP URLs
  * "--image-bg default" was renamed to "--image-bg checks"
  * fix --title-font fallback behaviour
  * fix delayed title display when using --title-font
- changes from 1.16.1:
  * fix reload after image rotation and similar (broken by 1.16)
* Mon Sep  5 2011 pascal.bleser@opensuse.org
- update to 1.16:
  * reload image after executing an action with the hold-action flag set
  * fix bug in --info (used to swallow the last output character in some cases)
  * add --draw-tinted option to make overlay text (filename, caption etc.)
    better readable
  * the --collage option (aka collage mode) is now deprecated
  * the feh-cam and gen-cam-menu tools are deprecated as well (but will remain
    in this distribution for at least 1 year)
  * the --filelist option now supports /dev/stdin (or "-" as shortcut)
  * several Xinerama fixes, only --fullscreen on screen != 0 is still broken
  * fix segfault when reloading no longer loadable (but still existing) images;
    feh will now display a warning and try to reload ad infinitum
  * fix memory leak in reload functionality for directories
  * when using --no-menus and clicking the menu button, feh will now ignore it
    instead of quitting (which was undocumented behaviour anyways)
* Sat Aug 20 2011 pascal.bleser@opensuse.org
- update to 1.15.1:
  * fix segfault when selecting menu items (broken by 1.15):
    https://github.com/derf/feh/issues/58>
* Mon Jul  4 2011 pascal.bleser@opensuse.org
- update to 1.14.2:
  * fixes a minor memory leak in the recursive file loader
  * the text drawn by --draw-filename is no longer cut off in certain
    circumstances
  * a toggle for the --info display has been added
  * you can now use --zoom 100 to always see images at 100%% in --fullscreen
    mode
* Thu May 19 2011 pascal.bleser@opensuse.org
- update to 1.14.1:
  * make zoom_default key work properly with --geometry
* Wed May 11 2011 pascal.bleser@opensuse.org
- update to 1.14:
  * thumbnail mode can now be controlled with keys: you can use next/prev to
    select an image and the render key to open it
  * when reading a directory, feh now reads the files in alphabetical order
    instead of a seemingly random order by default
  * only create caption directory when actually writing out a caption
  * the --menu-bg option has been deprecated; it will be removed along with
  - -menu-style by the end of 2012
  * show certain warnings in the image window as well as on the commandline
  * since the manual is way better structured and more detailed than the --help
    output, it now simply refers to the manual
  * change a patch for NETWM fullscreen support to only apply to fullscreen
    windows: this fixes the moving windows bug in fluxbox (since fluxbox
    doesn't report its window border width)
  * fix --auto-zoom / --zoom max/fill documentation, the "Auto-Zoom" menu
    option is now always checked when these options are used
  * set _NET_WM_NAME and _NET_WM_ICON_NAME properties
  * the 'A' key (toggle_aliasing) now actually changes the current window, and
    not just the default for new windows
  * the zoom_default key now works fine with --scale-down
  * fix access of uninitialized memory / malloc/realloc clash in continued
    theme definition handling; having a theme line with just one option/value
    pair used to produce undefined behaviour
* Sat Apr 23 2011 pascal.bleser@opensuse.org
- update to 1.13:
  * the --bg options are now Xinerama-aware: that is, they set the image in the
    respective mode (scale/fill/max/center) on each Xinerama screen; use
  - -no-xinerama to disable this
  * for convenience, feh will now show all images in the current directory when
    invoked without file arguments
  * the --force-aliasing option was added with "A" as toggle
  * sending SIGUSR1 or SIGUSR2 in multiwindow mode reloads all images
  * unloadable images with image-related escapes (%%h etc) in --title no longer
    make feh segfault
  * the reload mechanism now immediately works (it used to take two tries)
* Sun Mar 13 2011 pascal.bleser@opensuse.org
- update to 1.12:
  * libcurl is used instead of wget for http:// images
  * the new --zoom max option can now be used to view images zoomed like in
  - -bg-max
  * the --builtin HTTP client has been removed
* Wed Feb  9 2011 pascal.bleser@opensuse.org
- update to 1.11.2:
  * fixes a hole when using feh with HTTP/FTP URLs: an attacker knowing the feh
    PID and the URL could make feh overwrite arbitrary user files with images
    by using symlinks to those files and a TOCTTOU attack on feh's unique
    filename mechanism; adds the --no-clobber switch to wget; an attacker can
    still create arbitrary files via dangling symlinks, but overwriting
    existing files is no longer possible; a proper fix (probably replacing wget
    with libcurl) will be provided in feh 2.0
* Thu Jan 27 2011 pascal.bleser@opensuse.org
- update to 1.11.1:
  * fixes the processing of keys when NumLock or similar modifiers are enabled
  * allows command line options to override those set in a theme (it used to be
    the other way around, which was counter-intuitive and therefore considered
    a bug)
  * in thumbnail mode, feh will now always report the correct dimensions, even
    for cached thumbnails
* Sat Jan 22 2011 pascal.bleser@opensuse.org
- update to 1.11:
  * key bindings are now 100%% configurable via ~/.config/feh/keys
  * addresses a few issues with --scale-down and moves the themes configuration
    from ~/.fehrc to ~/.config/feh/themes
  * the builtin HTTP client now has IPv6 support
* Sat Dec  4 2010 pascal.bleser@opensuse.org
- add patch to use getaddrinfo() and support IPv6
- update to 1.10.1:
  * fixes a buffer overflow in --draw-actions
  * fixes segfaults when trying to load several invalid images in a row
  * fixes parts of --scale-down
  * the default .fehrc no longer contains escape errors
* Fri Oct  8 2010 pascal.bleser@opensuse.org
- update to 1.10:
  * --bg-seamless has been replaced by --bg-max (like --bg-fill but with borders), which should be way more useful
  * it is now possible to display arbitrary information in the image by using the --info option
  * minor workarounds and improvements for scrolling and Xinerama handling have been made
  * this is also the first release in which the graphical (X11) parts of feh have been tested in a number of ways
* Tue Aug 24 2010 pascal@links2linux.de
- update to 1.9:
  * --scale-down now somewhat works with tiling window managers
  * zooming via keyboard has seen large improvements and can now also be done by pressing the Up/Down keys
  * image moving is now possible with CTRL + Arrow Keys
  * a few short option aliases for long-only options were added
  * the --menu-border option was removed because it is extremely useless
  * a few image menu background images were removed
* Fri Jun 25 2010 pascal@links2linux.de
- update to 1.8:
  * fixes a security issue with --wget-timestamps, which passed unescaped URLs to a system() call and thus allowed arbitrary code execution
  * disables fullscreen mode for the --thumbnail window (but allows the setting for the images opened from that window)
  * disables filelist saving for thumbnail mode, which caused undefined behaviour if the user removed a file before saving
  * --font now sets the global font
  * <keypad *> and <keypad /> were improved
  * feh now no longer adds "?something" to URLs before downloading them
* Wed Jun 23 2010 pascal@links2linux.de
- update to 1.7:
  * fixes a segmentation fault related to thumbnail mode
  * removes some duplicated (shift key) / undocumented key bindings
  * you can now set a slideshow delay but start the slideshow mode paused
  * caption mode now automatically creates the caption directory if it does not exist
* Mon Jun 14 2010 pascal@links2linux.de
- update to 1.6.1:
  * fixes omitted image borders in certain zoom levels
  * makes the -L, -u, and -U options work without a running X server
* Tue Jun  5 2007 toni@links2linux.de
- corrected BuildRequires for SuSE-10.0 and SuSE-10.1 build
- added debug_package
* Sun Dec  3 2006 oliver@links2linux.de
- rewrote spec for packman
- added feh-docsdir.diff
* Sat Jul 23 2005 guru@unixtech.be
- complete spec-file rewrite
- version 1.3.4
